# Copyright (c) 2006-2025 Broadcom. All Rights Reserved.
# Broadcom Confidential. The term "Broadcom" refers to Broadcom Inc.
# and/or its subsidiaries.

# ******* WARNING - AUTO GENERATED CODE - DO NOT EDIT *******

from pyVmomi.vim.fault import CpuIncompatible

class CpuIncompatible81EDX(CpuIncompatible):
   nx: bool
   ffxsr: bool
   rdtscp: bool
   lm: bool
   other: bool
   otherOnly: bool
